@@ -28,10 +28,8 @@
 #include "gstsearchfuncs.h"
 
 /* FIXME: "evil hack" alarm, we need a better way to get a category in here */
-#ifndef GST_DISABLE_GST_DEBUG
-extern GstDebugCategory *GST_CAT_AUTOPLUG_ATTEMPT;
+GST_DEBUG_CATEGORY_EXTERN (GST_CAT_AUTOPLUG_ATTEMPT);
 #define GST_CAT_DEFAULT GST_CAT_AUTOPLUG_ATTEMPT
-#endif
 
 /* function that really misses in GLib
  * though the GLib version should take a function as argument...
@@ -58,23 +56,21 @@ g_list_free_list_and_elements (GList *list)
  * Returns: TRUE, if both caps intersect.
  */
 gboolean
-gst_autoplug_caps_intersect (GstCaps *src, GstCaps *sink)
+gst_autoplug_caps_intersect (const GstCaps *src, const GstCaps *sink)
 {
   GstCaps *caps;
 
-  /* if there are no caps, we can link */
-  if ((src == NULL) && (sink == NULL))
-    return TRUE;
-
   /* get an intersection */
   caps = gst_caps_intersect (src, sink);
   
   /* if the caps can't link, there is no intersection */
-  if (caps == NULL)
+  if (gst_caps_is_empty (caps)) {
+    gst_caps_free (caps);
     return FALSE;
+  }
   
   /* hurrah, we can link, now remove the intersection */
-  gst_caps_unref (caps);
+  gst_caps_free (caps);
   return TRUE;
 }
 
@@ -88,7 +84,7 @@ gst_autoplug_caps_intersect (GstCaps *src, GstCaps *sink)
  * Returns: #GstPadTemplate that can connect to the given caps
  */
 GstPadTemplate *
-gst_autoplug_can_connect_src (GstElementFactory *fac, GstCaps *src)
+gst_autoplug_can_connect_src (GstElementFactory *fac, const GstCaps *src)
 {
   GList *templs;
   
@@ -117,7 +113,7 @@ gst_autoplug_can_connect_src (GstElementFactory *fac, GstCaps *src)
  * Returns: #GstPadTemplate that can connect to the given caps
  */
 GstPadTemplate *
-gst_autoplug_can_connect_sink (GstElementFactory *fac, GstCaps *sink)
+gst_autoplug_can_connect_sink (GstElementFactory *fac, const GstCaps *sink)
 {
   GList *templs;
   
@@ -331,7 +327,7 @@ gst_autoplug_factories_at_most_templates(GList *factories, GstPadDirection dir,
  * to get the shortest path.
  */
 GList *
-gst_autoplug_sp (GstCaps *srccaps, GstCaps *sinkcaps, GList *factories)
+gst_autoplug_sp (const GstCaps *srccaps, const GstCaps *sinkcaps, GList *factories)
 {
   GList *factory_nodes = NULL;
   guint curcost = GST_AUTOPLUG_MAX_COST; /* below this cost, there is no path */
@@ -340,11 +336,9 @@ gst_autoplug_sp (GstCaps *srccaps, GstCaps *sinkcaps, GList *factories)
   g_return_val_if_fail (srccaps != NULL, NULL);
   g_return_val_if_fail (sinkcaps != NULL, NULL);
   
-  GST_INFO ("attempting to autoplug via shortest path from %s to %s", 
-	    gst_caps_get_mime (srccaps), gst_caps_get_mime (sinkcaps));
+  GST_INFO ("attempting to autoplug via shortest path from %"
+      GST_PTR_FORMAT " to %" GST_PTR_FORMAT, srccaps, sinkcaps);
 
-  gst_caps_debug (srccaps, "source caps");
-  gst_caps_debug (sinkcaps, "sink caps");
   /* wrap all factories as GstAutoplugNode 
    * initialize the cost */
   while (factories)
@@ -352,17 +346,17 @@ gst_autoplug_sp (GstCaps *srccaps, GstCaps *sinkcaps, GList *factories)
     GstAutoplugNode *node = g_new0 (GstAutoplugNode, 1);
     node->prev = NULL;
     node->fac = (GstElementFactory *) factories->data;
-    GST_DEBUG ("trying with %s", node->fac->details->longname);
+    GST_DEBUG ("trying with %s", node->fac->details.longname);
     node->templ = gst_autoplug_can_connect_src (node->fac, srccaps);
     node->cost = (node->templ ? gst_autoplug_get_cost (node->fac) 
 		              : GST_AUTOPLUG_MAX_COST);
     node->endpoint = gst_autoplug_can_connect_sink (node->fac, sinkcaps);
     if (node->templ && node->endpoint)
       GST_DEBUG ("%s makes connection possible",
-		 node->fac->details->longname);
+		 node->fac->details.longname);
     else
       GST_DEBUG ("direct connection with %s not possible",
-		 node->fac->details->longname);
+		 node->fac->details.longname);
     if ((node->endpoint != NULL) && 
 	((bestnode == NULL) || (node->cost < bestnode->cost)))
     {
