@@ -15,6 +15,11 @@
  * License along with this library; if not, write to the
  * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
  * Boston, MA 02111-1307, USA.
+ *
+ *
+ * Much of the code in this file is taken from the Linux kernel. 
+ * The code is relicensed under the LGPL with the kind permission of
+ * Linus Torvalds,Ralf Baechle and Alan Cox
  */
 
 #ifndef __GST_ATOMIC_IMPL_H__
@@ -206,7 +211,8 @@ gst_atomic_int_dec_and_test (GstAtomicInt *aint)
 }
 
 /***** Sun SPARC *****/
-#elif defined(HAVE_CPU_SPARC) && defined(__GNUC__)
+#elif 0 && defined(HAVE_CPU_SPARC) && defined(__GNUC__)
+/* allegedly broken again */
 
 GST_INLINE_FUNC void 	gst_atomic_int_destroy 	(GstAtomicInt *aint) { } 
 
@@ -323,7 +329,9 @@ gst_atomic_int_dec_and_test (GstAtomicInt *aint)
 }
 
 /***** MIPS *****/
-#elif defined(HAVE_CPU_MIPS) && defined(__GNUC__)
+/* This is disabled because the asm code is broken on most MIPS
+ * processors and doesn't generally compile. */
+#elif defined(HAVE_CPU_MIPS) && defined(__GNUC__) && 0
 
 GST_INLINE_FUNC void 	gst_atomic_int_init 	(GstAtomicInt *aint, gint val) { aint->counter = val; }
 GST_INLINE_FUNC void 	gst_atomic_int_destroy 	(GstAtomicInt *aint) { } 
