@@ -80,6 +80,7 @@ extern GType _gst_element_type;
 #define GST_ELEMENT_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST ((klass), GST_TYPE_ELEMENT, GstElementClass))
 
 /* convenience functions */
+#ifndef GST_DISABLE_DEPRECATED
 #ifdef G_HAVE_ISO_VARARGS
 #define GST_ELEMENT_QUERY_TYPE_FUNCTION(functionname, ...) \
 	GST_QUERY_TYPE_FUNCTION (GstElement*, functionname, __VA_ARGS__);
@@ -95,6 +96,7 @@ extern GType _gst_element_type;
 #define GST_ELEMENT_EVENT_MASK_FUNCTION(functionname, a...) \
 	GST_EVENT_MASK_FUNCTION (GstElement*, functionname, a);
 #endif
+#endif
 
 typedef enum {
   /* element is complex (for some def.) and generally require a cothread */
@@ -122,7 +124,7 @@ typedef enum {
   GST_ELEMENT_LOCKED_STATE,
 
   /* element is in error */
-  GST_ELEMENT_ERROR,
+  GST_ELEMENT_IN_ERROR,
 
   /* use some padding for future expansion */
   GST_ELEMENT_FLAG_LAST		= GST_OBJECT_FLAG_LAST + 16
@@ -139,6 +141,16 @@ typedef enum {
 #define GST_ELEMENT_CLOCK(obj)			(((GstElement*)(obj))->clock)
 #define GST_ELEMENT_PADS(obj)			((obj)->pads)
 
+#define GST_ELEMENT_ERROR(el, domain, code, message, debug) G_STMT_START { \
+  gchar *__msg = _gst_element_error_printf message; \
+  gchar *__dbg = _gst_element_error_printf debug; \
+  GST_ERROR_OBJECT (el, "%s", __msg); \
+  GST_ERROR_OBJECT (el, "%s", __dbg); \
+  gst_element_error_full (GST_ELEMENT(el), \
+  GST_ ## domain ## _ERROR, GST_ ## domain ## _ERROR_ ## code, \
+  __msg, __dbg, __FILE__, GST_FUNCTION, __LINE__); \
+} G_STMT_END
+
 typedef struct _GstElementFactory GstElementFactory;
 typedef struct _GstElementFactoryClass GstElementFactoryClass;
 
@@ -159,7 +171,7 @@ struct _GstElement {
 
   /* allocated clock */
   GstClock		*clock;
-  GstClockTime		 base_time;
+  GstClockTimeDiff    	base_time; /* NULL/READY: 0 - PAUSED: current time - PLAYING: difference to clock */
 
   /* element pads */
   guint16 		numpads;
@@ -195,9 +207,9 @@ struct _GstElementClass {
   void (*state_change)	(GstElement *element, GstElementState old, GstElementState state);
   void (*new_pad)	(GstElement *element, GstPad *pad);
   void (*pad_removed)	(GstElement *element, GstPad *pad);
-  void (*error)		(GstElement *element, GstElement *source, gchar *error);
+  void (*error)		(GstElement *element, GstElement *source, GError *error, gchar *debug);
   void (*eos)		(GstElement *element);
-  void (*found_tag)	(GstElement *element, GstElement *source, GstTagList *tag_list);
+  void (*found_tag)	(GstElement *element, GstElement *source, const GstTagList *tag_list);
 
   /* local pointers for get/set */
   void (*set_property) 	(GObject *object, guint prop_id, const GValue *value, GParamSpec *pspec);
@@ -232,6 +244,7 @@ struct _GstElementClass {
   GstIndex*		(*get_index)		(GstElement *element);
   void			(*set_index)		(GstElement *element, GstIndex *index);
 
+  GstElementStateReturn	(*set_state)		(GstElement *element, GstElementState state);
   gpointer _gst_reserved[GST_PADDING];
 };
 
@@ -239,11 +252,11 @@ void			gst_element_class_add_pad_template	(GstElementClass *klass, GstPadTemplat
 void                    gst_element_class_install_std_props	(GstElementClass *klass,
 								 const gchar      *first_name, ...);
 void			gst_element_class_set_details		(GstElementClass *klass,
-								 GstElementDetails *details);
+								 const GstElementDetails *details);
 
 #define 		gst_element_default_deep_notify 	gst_object_default_deep_notify
 
-void 			gst_element_default_error		(GObject *object, GstObject *orig, gchar *error);
+void 			gst_element_default_error		(GObject *object, GstObject *orig, GError *error, gchar *debug);
 
 GType			gst_element_get_type		(void);
 void			gst_element_set_loop_function	(GstElement *element,
@@ -277,6 +290,10 @@ GstClock*		gst_element_get_clock 		(GstElement *element);
 void			gst_element_set_clock 		(GstElement *element, GstClock *clock);
 GstClockReturn		gst_element_clock_wait 		(GstElement *element, 
 							 GstClockID id, GstClockTimeDiff *jitter);
+GstClockTime		gst_element_get_time		(GstElement *element);
+gboolean		gst_element_wait		(GstElement *element, GstClockTime timestamp);
+void			gst_element_set_time		(GstElement *element, GstClockTime time);
+void			gst_element_adjust_time		(GstElement *element, GstClockTimeDiff diff);
  
 /* indexs */
 gboolean		gst_element_is_indexable	(GstElement *element);
@@ -305,7 +322,7 @@ G_CONST_RETURN GList*
 			gst_element_get_pad_list	(GstElement *element);
 GstPad*			gst_element_get_compatible_pad	(GstElement *element, GstPad *pad);
 GstPad*			gst_element_get_compatible_pad_filtered (GstElement *element, GstPad *pad, 
-							 GstCaps *filtercaps);
+							 const GstCaps *filtercaps);
 
 GstPadTemplate*		gst_element_class_get_pad_template	(GstElementClass *element_class, const gchar *name);
 GList*                  gst_element_class_get_pad_template_list (GstElementClass *element_class);
@@ -317,7 +334,7 @@ gboolean		gst_element_link		(GstElement *src, GstElement *dest);
 gboolean		gst_element_link_many 		(GstElement *element_1, 
 							 GstElement *element_2, ...);
 gboolean		gst_element_link_filtered 	(GstElement *src, GstElement *dest,
-							 GstCaps *filtercaps);
+							 const GstCaps *filtercaps);
 void			gst_element_unlink 		(GstElement *src, GstElement *dest);
 void			gst_element_unlink_many 	(GstElement *element_1, 
 							 GstElement *element_2, ...);
@@ -326,7 +343,7 @@ gboolean		gst_element_link_pads		(GstElement *src, const gchar *srcpadname,
 							 GstElement *dest, const gchar *destpadname);
 gboolean		gst_element_link_pads_filtered 	(GstElement *src, const gchar *srcpadname,
 							 GstElement *dest, const gchar *destpadname,
-							 GstCaps *filtercaps);
+							 const GstCaps *filtercaps);
 void			gst_element_unlink_pads		(GstElement *src, const gchar *srcpadname,
 							 GstElement *dest, const gchar *destpadname);
 
@@ -345,13 +362,16 @@ gboolean		gst_element_convert		(GstElement *element,
 		 					 GstFormat  src_format,  gint64  src_value,
 							 GstFormat *dest_format, gint64 *dest_value);
 
-void			gst_element_found_tags		(GstElement *element, GstTagList *tag_list);
+void			gst_element_found_tags		(GstElement *element, const GstTagList *tag_list);
 void			gst_element_found_tags_for_pad	(GstElement *element, GstPad *pad, GstClockTime timestamp, 
 							 GstTagList *list);
 
 void			gst_element_set_eos		(GstElement *element);
 
-void 			gst_element_error 		(GstElement *element, const gchar *error, ...);
+gchar *			_gst_element_error_printf	(const gchar *format, ...);
+void			gst_element_error_full		(GstElement *element, GQuark domain, gint code, 
+							 gchar *message, gchar *debug, 
+							 const gchar *file, const gchar *function, gint line);
 
 gboolean		gst_element_is_locked_state	(GstElement *element);
 void			gst_element_set_locked_state	(GstElement *element, gboolean locked_state);
@@ -420,7 +440,6 @@ GType			gst_element_factory_get_element_type	(GstElementFactory *factory);
 G_CONST_RETURN gchar *	gst_element_factory_get_longname	(GstElementFactory *factory);
 G_CONST_RETURN gchar *	gst_element_factory_get_klass		(GstElementFactory *factory);
 G_CONST_RETURN gchar *	gst_element_factory_get_description  	(GstElementFactory *factory);
-G_CONST_RETURN gchar *	gst_element_factory_get_version      	(GstElementFactory *factory);
 G_CONST_RETURN gchar *	gst_element_factory_get_author		(GstElementFactory *factory);
 guint			gst_element_factory_get_num_pad_templates (GstElementFactory *factory);
 G_CONST_RETURN GList *	gst_element_factory_get_pad_templates	(GstElementFactory *factory);
@@ -432,9 +451,9 @@ GstElement*		gst_element_factory_create		(GstElementFactory *factory,
 GstElement*		gst_element_factory_make		(const gchar *factoryname, const gchar *name);
 
 gboolean		gst_element_factory_can_src_caps	(GstElementFactory *factory,
-								 GstCaps *caps);
+								 const GstCaps *caps);
 gboolean		gst_element_factory_can_sink_caps	(GstElementFactory *factory,
-								 GstCaps *caps);
+								 const GstCaps *caps);
 
 void			__gst_element_factory_add_pad_template	(GstElementFactory *elementfactory,
 								 GstPadTemplate *templ);
