@@ -143,7 +143,9 @@ static void
 gst_thread_class_init (gpointer g_class, gpointer class_data)
 {
   GObjectClass *gobject_class = G_OBJECT_CLASS (g_class);
+#ifndef GST_DISABLE_LOADSAVE
   GstObjectClass *gstobject_class = GST_OBJECT_CLASS (g_class);
+#endif
   GstElementClass *gstelement_class = GST_ELEMENT_CLASS (g_class);
   GstBinClass *gstbin_class = GST_BIN_CLASS (g_class);
   GstThreadClass *klass = GST_THREAD_CLASS (g_class);
@@ -474,9 +476,13 @@ gst_thread_change_state (GstElement *element)
       /* it should be dead now */
       break;
     default:
-      GST_ERROR_OBJECT (element, "UNHANDLED STATE CHANGE! %x", 
+      GST_ERROR_OBJECT (element, "unhandled state change! %x", 
                         GST_STATE_TRANSITION (element));
+      g_warning ("thread %s: UNHANDLED STATE CHANGE! %x", 
+                        GST_STR_NULL (GST_OBJECT_NAME (element)), GST_STATE_TRANSITION (element));
+      /* FIXME: not doable with current threading mess:
       g_assert_not_reached ();
+      */
       break;
   }
 
