@@ -30,7 +30,6 @@
 #include "gstmarshal.h"
 
 #include <string.h>
-#include <ctype.h>
 
 GST_DEBUG_CATEGORY_STATIC (gst_uri_handler_debug);
 #define GST_CAT_DEFAULT gst_uri_handler_debug
@@ -68,13 +67,12 @@ gst_uri_handler_base_init (gpointer g_class)
   static gboolean initialized = FALSE;
 
   if (!initialized) {
-    g_signal_new ("new_uri", GST_TYPE_URI_HANDLER, G_SIGNAL_RUN_LAST,
+    g_signal_new ("new-uri", GST_TYPE_URI_HANDLER, G_SIGNAL_RUN_LAST,
 	    G_STRUCT_OFFSET (GstURIHandlerInterface, new_uri), NULL, NULL,
 	    gst_marshal_VOID__STRING, G_TYPE_NONE, 1, G_TYPE_STRING);
     initialized = TRUE;
   }
 }
-                                                                                                                    
 
 static void
 gst_uri_protocol_check_internal (const gchar *uri, gchar **endptr)
@@ -84,9 +82,9 @@ gst_uri_protocol_check_internal (const gchar *uri, gchar **endptr)
   g_assert (uri != NULL);
   g_assert (endptr != NULL);
 
-  if (isalpha (*check)) {
+  if (g_ascii_isalpha (*check)) {
     check++;
-    while (isalnum (*check)) check++;
+    while (g_ascii_isalnum (*check)) check++;
   }
 
   *endptr = check;
