@@ -22,7 +22,6 @@
 
 #include <stdio.h>
 #include <string.h>
-#include <ctype.h>
 
 #include "gst_private.h"
 #include "gstutils.h"
@@ -209,7 +208,7 @@ gst_util_set_object_arg (GObject * object, const gchar * name, const gchar * val
 	case G_TYPE_BOOLEAN:{
 	  gboolean i = FALSE;
 
-	  if (!g_strncasecmp ("true", value, 4))
+	  if (!g_ascii_strncasecmp ("true", value, 4))
 	    i = TRUE;
 	  g_object_set (G_OBJECT (object), name, i, NULL);
 	  break;
@@ -265,8 +264,6 @@ gst_util_set_object_arg (GObject * object, const gchar * name, const gchar * val
  */
 
 #include "gstpad.h"
-#include "gsttype.h"
-#include "gstprops.h"
 
 static void
 string_append_indent (GString * str, gint count)
@@ -277,102 +274,6 @@ string_append_indent (GString * str, gint count)
     g_string_append_c (str, ' ');
 }
 
-static void
-gst_print_props (GString *buf, gint indent, GList *props, gboolean showname)
-{
-  GList *elem;
-  guint width = 0;
-  GstPropsType type;
-
-  if (showname)
-    for (elem = props; elem; elem = g_list_next (elem)) {
-      GstPropsEntry *prop = elem->data;
-      const gchar *name = gst_props_entry_get_name (prop);
-
-      if (width < strlen (name))
-	width = strlen (name);
-    }
-
-  for (elem = props; elem; elem = g_list_next (elem)) {
-    GstPropsEntry *prop = elem->data;
-
-    string_append_indent (buf, indent);
-    if (showname) {
-      const gchar *name = gst_props_entry_get_name (prop);
-
-      g_string_append (buf, name);
-      string_append_indent (buf, 2 + width - strlen (name));
-    }
-
-    type = gst_props_entry_get_props_type (prop);
-    switch (type) {
-      case GST_PROPS_INT_TYPE:
-      {
-	gint val;
-	gst_props_entry_get_int (prop, &val);
-	g_string_append_printf (buf, "%d (int)\n", val);
-	break;
-      }
-      case GST_PROPS_INT_RANGE_TYPE:
-      {
-	gint min, max;
-	gst_props_entry_get_int_range (prop, &min, &max);
-	g_string_append_printf (buf, "%d - %d (int)\n", min, max);
-	break;
-      }
-      case GST_PROPS_FLOAT_TYPE:
-      {
-	gfloat val;
-	gst_props_entry_get_float (prop, &val);
-	g_string_append_printf (buf, "%f (float)\n", val);
-	break;
-      }
-      case GST_PROPS_FLOAT_RANGE_TYPE:
-      {
-	gfloat min, max;
-	gst_props_entry_get_float_range (prop, &min, &max);
-	g_string_append_printf (buf, "%f - %f (float)\n", min, max);
-	break;
-      }
-      case GST_PROPS_BOOLEAN_TYPE:
-      {
-	gboolean val;
-	gst_props_entry_get_boolean (prop, &val);
-	g_string_append_printf (buf, "%s\n", val ? "TRUE" : "FALSE");
-	break;
-      }
-      case GST_PROPS_STRING_TYPE:
-      {
-	const gchar *val;
-	gst_props_entry_get_string (prop, &val);
-	g_string_append_printf (buf, "\"%s\"\n", val);
-	break;
-      }
-      case GST_PROPS_FOURCC_TYPE:
-      {
-	guint32 val;
-	gst_props_entry_get_fourcc_int (prop, &val);
-	g_string_append_printf (buf, "'%c%c%c%c' (fourcc)\n",
-		                (gchar)( val        & 0xff),
-				(gchar)((val >> 8)  & 0xff),
-				(gchar)((val >> 16) & 0xff),
-				(gchar)((val >> 24) & 0xff));
-	break;
-      }
-      case GST_PROPS_LIST_TYPE:
-      {
-	const GList *list;
-	gst_props_entry_get_list (prop, &list);
-	gst_print_props (buf, indent + 2, (GList *)list, FALSE);
-	break;
-      }
-      default:
-	g_string_append_printf (buf, "unknown proptype %d\n", type);
-	break;
-    }
-  }
-}
-
 /**
  * gst_print_pad_caps:
  * @buf: the buffer to print the caps in
@@ -396,23 +297,11 @@ gst_print_pad_caps (GString * buf, gint indent, GstPad * pad)
     g_string_printf (buf, "%s:%s has no capabilities", GST_DEBUG_PAD_NAME (pad));
   }
   else {
-    gint capx = 0;
+    char *s;
 
-    while (caps) {
-      GstType *type;
-
-      string_append_indent (buf, indent);
-      g_string_append_printf (buf, "Cap[%d]: %s\n", capx++, caps->name);
-
-      type = gst_type_find_by_id (caps->id);
-      string_append_indent (buf, indent + 2);
-      g_string_append_printf (buf, "MIME type: %s\n", type->mime ? type->mime : "unknown/unknown");
-
-      if (caps->properties)
-	gst_print_props (buf, indent + 4, caps->properties->properties, TRUE);
-
-      caps = caps->next;
-    }
+    s = gst_caps_to_string(caps);
+    g_string_append(buf, s);
+    g_free(s);
   }
 }
 
