@@ -1,133 +1,62 @@
+/* GStreamer
+ * Copyright (C) 1999,2000 Erik Walthinsen <omega@cse.ogi.edu>
+ *               2000 Wim Taymans <wtay@chello.be>
+ *               2004 Thomas Vander Stichele <thomas@apestaart.org>
+ *
+ * gst-inspect.c: tool to inspect the GStreamer registry
+ *
+ * This library is free software; you can redistribute it and/or
+ * modify it under the terms of the GNU Library General Public
+ * License as published by the Free Software Foundation; either
+ * version 2 of the License, or (at your option) any later version.
+ *
+ * This library is distributed in the hope that it will be useful,
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
+ * Library General Public License for more details.
+ *
+ * You should have received a copy of the GNU Library General Public
+ * License along with this library; if not, write to the
+ * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
+ * Boston, MA 02111-1307, USA.
+ */
+
 #ifdef HAVE_CONFIG_H
 #  include "config.h"
 #endif
 
 #include <gst/gst.h>
 #include <gst/control/control.h>
+
+#include "gst/gst-i18n-app.h"
+
 #include <string.h>
+#include <locale.h>
 
 static void
-print_prop (GstPropsEntry *prop, gboolean showname, const gchar *pfx)
+print_caps (const GstCaps *caps, const gchar *pfx)
 {
-  GstPropsType type;
+  char *s, *tmp;
+  char **v;
 
-  if (showname)
-    g_print("%s%-20.20s: ", pfx, gst_props_entry_get_name (prop));
-  else
-    g_print(pfx);
-
-  type = gst_props_entry_get_props_type (prop);
-
-  switch (type) {
-    case GST_PROPS_INT_TYPE:
-    {
-      gint val;
-      gst_props_entry_get_int (prop, &val);
-      g_print("Integer: %d\n", val);
-      break;
-    }
-    case GST_PROPS_INT_RANGE_TYPE:
-    {
-      gint min, max;
-      gst_props_entry_get_int_range (prop, &min, &max);
-      g_print("Integer range: %d - %d\n", min, max);
-      break;
-    }
-    case GST_PROPS_FLOAT_TYPE:
-    {
-      gfloat val;
-      gst_props_entry_get_float (prop, &val);
-      g_print("Float: %g\n", val);
-      break;
-    }
-    case GST_PROPS_FLOAT_RANGE_TYPE:
-    {
-      gfloat min, max;
-      gst_props_entry_get_float_range (prop, &min, &max);
-      g_print("Float range: %g - %g\n", min, max);
-      break;
-    }
-    case GST_PROPS_BOOLEAN_TYPE:
-    {
-      gboolean val;
-      gst_props_entry_get_boolean (prop, &val);
-      g_print("Boolean: %s\n", val ? "TRUE" : "FALSE");
-      break;
-    }
-    case GST_PROPS_STRING_TYPE:
-    {
-      const gchar *val;
-      gst_props_entry_get_string (prop, &val);
-      g_print("String: \"%s\"\n", val);
-      break;
-    }
-    case GST_PROPS_FOURCC_TYPE:
-    {
-      guint32 val;
-      gst_props_entry_get_fourcc_int (prop, &val);
-      g_print("FourCC: '%c%c%c%c'\n",
-             (gchar)( val        & 0xff),
-             (gchar)((val >> 8)  & 0xff),
-             (gchar)((val >> 16) & 0xff),
-             (gchar)((val >> 24) & 0xff));
-      break;
-    }
-    case GST_PROPS_LIST_TYPE:
-    {
-      const GList *list;
-      gchar *longprefix;
-
-      gst_props_entry_get_list (prop, &list);
-      g_print ("List:\n");
-      longprefix = g_strdup_printf ("%s ", pfx);
-      while (list) {
-        GstPropsEntry *listentry;
-
-        listentry = (GstPropsEntry*) (list->data);
-        print_prop (listentry, FALSE, longprefix);
-
-        list = g_list_next (list);
-      }
-      g_free (longprefix);
-      break;
-    }
-    default:
-      g_print("unknown props %d\n", type);
-  }
-}
-
-static void
-print_props (GstProps *properties, const gchar *pfx)
-{
-  GList *props;
-  GstPropsEntry *prop;
-
-  props = properties->properties;
-  while (props) {
-    prop = (GstPropsEntry*)(props->data);
-    props = g_list_next(props);
-
-    print_prop(prop,TRUE,pfx);
-  }
-}
-
-static void
-print_caps (GstCaps *caps, const gchar *pfx)
-{
-  while (caps) {
-    g_print ("%s'%s': (%sfixed)\n", pfx, caps->name, (GST_CAPS_IS_FIXED (caps) ? "" : "NOT "));
-    g_print ("%s  MIME type: '%s':\n", pfx, gst_caps_get_mime (caps));
-
-    if (caps->properties) {
-      gchar *prefix = g_strdup_printf ("%s  ", pfx);
-
-      print_props(caps->properties, prefix);
-
-      g_free (prefix);
-    }
-
-    caps = caps->next;
-  }
+  s = gst_caps_to_string (caps);
+  
+  tmp = g_strdup_printf ("\n  %s", pfx);
+  v = g_strsplit (s, ", ", -1);
+  g_free (s);
+  s = g_strjoinv (tmp, v);
+  g_strfreev (v);
+  g_free (tmp);
+  
+  tmp = g_strdup_printf ("\n%s", pfx);
+  v = g_strsplit (s, "; ", -1);
+  g_free (s);
+  s = g_strjoinv (tmp, v);
+  g_free (tmp);
+  g_strfreev (v);
+  
+  g_print ("%s%s\n", pfx, s);
+  g_free(s);
 }
 
 static void
@@ -353,7 +282,7 @@ print_element_properties (GstElement *element)
           g_print("%-23.23s URI", "");
         }
         if (param->value_type == GST_TYPE_CAPS) {
-          GstCaps *caps = g_value_peek_pointer (&value);
+          const GstCaps *caps = gst_value_get_caps (&value);
 
           if (!caps)
             g_print("%-23.23s Caps (NULL)", "");
@@ -464,7 +393,6 @@ print_element_info (GstElementFactory *factory)
   GstElement *element;
   GstObjectClass *gstobject_class;
   GstElementClass *gstelement_class;
-  GList *pads;
   GstPad *pad;
   GstRealPad *realpad;
   GstPadTemplate *padtemplate;
@@ -494,6 +422,8 @@ print_element_info (GstElementFactory *factory)
 
   g_print ("Pad Templates:\n");
   if (factory->numpadtemplates) {
+    const GList *pads;
+
     pads = factory->padtemplates;
     while (pads) {
       padtemplate = (GstPadTemplate*)(pads->data);
@@ -672,9 +602,9 @@ print_element_info (GstElementFactory *factory)
         g_print ("      Has custom intconnfunc(): %s\n",
                 GST_DEBUG_FUNCPTR_NAME(realpad->intlinkfunc));
 
-      if (realpad->bufferpoolfunc)
-        g_print ("      Has bufferpoolfunc(): %s\n",
-                GST_DEBUG_FUNCPTR_NAME(realpad->bufferpoolfunc));
+      if (realpad->bufferallocfunc)
+        g_print ("      Has bufferallocfunc(): %s\n",
+                GST_DEBUG_FUNCPTR_NAME(realpad->bufferallocfunc));
 
       if (pad->padtemplate)
         g_print ("    Pad Template: '%s'\n",
@@ -723,6 +653,13 @@ print_element_info (GstElementFactory *factory)
               ((GParamSpecFloat *) specs[x])->minimum,
               ((GParamSpecFloat *) specs[x])->maximum);
             break;
+          case G_TYPE_DOUBLE:
+            g_print ("Double. Default: %-8.8s %15.7g\n", "",
+              ((GParamSpecDouble *) specs[x])->default_value);
+            g_print ("%-23.23s Range: %15.7g - %15.7g", "",
+              ((GParamSpecDouble *) specs[x])->minimum,
+              ((GParamSpecDouble *) specs[x])->maximum);
+            break;
         default: g_print ("unknown %ld", G_PARAM_SPEC_VALUE_TYPE (specs[x]));
         }
         g_print ("\n");
@@ -848,15 +785,17 @@ print_element_list (void)
         GstTypeFindFactory *factory;
 
         factory = GST_TYPE_FIND_FACTORY (feature);
+        g_print ("%s: %s: ", plugin->desc.name, gst_plugin_feature_get_name (feature));
         if (factory->extensions) {
 	  guint i = 0;
-          g_print ("%s type: ", plugin->desc.name);
 	  while (factory->extensions[i]) {
 	    g_print ("%s%s", i > 0 ? ", " : "", factory->extensions[i]);
 	    i++;
 	  }
-	} else
-          g_print ("%s type: N/A\n", plugin->desc.name);
+          g_print ("\n");
+	} else {
+          g_print ("no extensions\n");
+        }
       }
       else if (GST_IS_SCHEDULER_FACTORY (feature)) {
         GstSchedulerFactory *factory;
@@ -975,12 +914,16 @@ main (int argc, char *argv[])
   gchar *so;
   struct poptOption options[] = {
     {"gst-inspect-plugin", 'p', POPT_ARG_STRING|POPT_ARGFLAG_STRIP, NULL, 0,
-                   "Show plugin details", NULL},
+                   N_("Show plugin details"), NULL},
     {"gst-inspect-scheduler", 's', POPT_ARG_STRING|POPT_ARGFLAG_STRIP, NULL, 0,
-                   "Show scheduler details", NULL},
+                   N_("Show scheduler details"), NULL},
     POPT_TABLEEND
   };
 
+  bindtextdomain (GETTEXT_PACKAGE, LOCALEDIR);
+  bind_textdomain_codeset(GETTEXT_PACKAGE, "UTF-8");
+  textdomain (GETTEXT_PACKAGE);
+
   gst_init_with_popt_table (&argc, &argv, options);
   gst_control_init (&argc, &argv);
 
